@@ -1,11 +1,11 @@
 require 'net/http'
 require 'openssl'
 require 'json'
-require 'redis'
 
 require_relative 'gitlab_config'
 require_relative 'gitlab_logger'
 require_relative 'gitlab_access'
+require_relative 'gitlab_redis'
 require_relative 'httpunix'
 
 class GitlabNet
@@ -14,7 +14,7 @@ class GitlabNet
   CHECK_TIMEOUT = 5
   READ_TIMEOUT = 300
 
-  def check_access(cmd, repo, actor, changes)
+  def check_access(cmd, repo, actor, changes, protocol)
     project_name = repo.gsub("'", "")
     project_name = project_name.gsub(/\.git\Z/, "")
     project_name = project_name.gsub(/\A\//, "")
@@ -24,6 +24,7 @@ class GitlabNet
       action: cmd,
       changes: changes,
       project: project_name,
+      protocol: protocol
     }
 
     if actor =~ /\Akey\-\d+\Z/
@@ -38,7 +39,7 @@ class GitlabNet
     if resp.code == '200'
       GitAccessStatus.create_from_json(resp.body)
     else
-      GitAccessStatus.new(false, 'API is not accessible')
+      GitAccessStatus.new(false, 'API is not accessible', nil)
     end
   end
 
